.. _summarizer:

================================================
Summarizer subpackage :mod:`melusine.summarizer`
================================================

TODO : ADD DESCRIPTION OF THE SUBPACKAGE

------------------
List of submodules
------------------
.. contents::
   :local:


.. _keywords_generator:

KeywordsGenerator :mod:`melusine.summarizer.keywords_generator`
---------------------------------------------------------------

.. automodule:: melusine.summarizer.keywords_generator
   :members:
   :undoc-members:
   :show-inheritance:
